@@ -1,33 +1,34 @@
 #!/usr/bin/perl -w
 use strict;
-use 5.006001;
+use 5.008003;
+use Carp;
 
 use Config;
-use Carp;
 use Cwd;
-use File::Spec;
-use File::Path;
-use File::Copy;
 use Data::Dumper;
 use File::Basename;
+use File::Copy;
+use File::Path;
+use File::Spec;
+use File::Spec::Functions;
 my $findbin;
 BEGIN { $findbin = dirname $0 }
 
-use lib File::Spec->catdir($findbin, 'lib');
-use lib File::Spec->catdir($findbin, 'lib', 'inc');
 use lib $findbin;
-use lib File::Spec->catdir($findbin, 'inc');
+use fallback 'inc', 'lib', catdir($findbin, 'inc');
+
 use Test::Smoke::SysInfo;
 use Test::Smoke::Util qw(do_pod2usage whereis);
+use Test::Smoke::Util::FindHelpers ':all';
 
 # $Id$
 use vars qw($VERSION $conf);
-$VERSION = '0.081';
+$VERSION = '0.090';
 
 use Getopt::Long;
-my %options = ( 
-        config  => undef, 
-        jcl     => undef, 
+my %options = (
+        config  => undef,
+        jcl     => undef,
         log     => undef,
         default => undef,
         prefix  => undef,
@@ -35,16 +36,16 @@ my %options = (
         usedft  => undef,
         );
 my $myusage = "Usage: $0 -p <prefix>[ -d <defaultsprefix>]";
-GetOptions( \%options, 
-        'config|c=s', 'jcl|j=s', 'log|l=s', 
+GetOptions( \%options,
+        'config|c=s', 'jcl|j=s', 'log|l=s',
         'prefix|p=s', 'default|d:s', 'usedft|des',
 
         'help|h', 'man',
         ) or do_pod2usage( verbose => 1, myusage => $myusage );
 
-$options{ man} and 
+$options{ man} and
 do_pod2usage( verbose => 2, exitval => 0, myusage => $myusage );
-$options{help} and 
+$options{help} and
 do_pod2usage( verbose => 1, exitval => 0, myusage => $myusage );
 
 $options{prefix} = 'smokecurrent' unless defined $options{prefix};
@@ -58,7 +59,7 @@ foreach my $opt (qw( config jcl log )) {
 {
     local $@;
     eval { require $options{config} };
-    my $load_error = $@; 
+    my $load_error = $@;
     unless ( $load_error ) {
         $options{oldcfg} = 1;
         print "Using '$options{config}' for defaults.\n";
@@ -98,7 +99,7 @@ unless ( $options{oldcfg} ) {
 
 =head1 NAME
 
-configsmoke.pl - Create a configuration for B<smokeperl.pl>
+configsmoke.pl - Create a configuration for B<tssmokeperl.pl>
 
 =head1 SYNOPSIS
 
@@ -106,7 +107,7 @@ configsmoke.pl - Create a configuration for B<smokeperl.pl>
 
 or regenerate from previous _config:
 
-    $ perl configsmoke.pl -p <prefix> -des 
+    $ perl configsmoke.pl -p <prefix> -des
 
 =head1 OPTIONS
 
@@ -130,10 +131,9 @@ my %config = ( perl_version => $conf->{perl_version} || 'blead' );
 my %mailers = get_avail_mailers();
 my @mailers = sort keys %mailers;
 my @syncers = get_avail_sync();
-my $syncmsg = join "\n", @{ { 
-    git      => "\tgit - Use a git-repository.",
-    rsync    => "\trsync - Use the rsync(1) program [preferred]",
-    ftp      => "\tftp - Use Net::FTP to sync from APC [!slow!]",
+my $syncmsg = join "\n", @{ {
+    git      => "\tgit - Use a git-repository [preferred]",
+    rsync    => "\trsync - Use the rsync(1) program",
     copy     => "\tcopy - Use File::Copy to copy from a local directory",
     hardlink => "\thardlink - Copy from a local directory using link()",
     snapshot => "\tsnapshot - Get a snapshot using Net::FTP (or LWP::Simple)",
@@ -145,82 +145,23 @@ my %vdirs = map {
     my $vdir = $_;
     is_vms and $vdir =~ tr/.//d;
     ( $_ => $vdir )
-} qw( 5.8.x 5.10.x 5.12.x 5.14.x 5.16.x );
+} qw( 5.18.x 5.20.x 5.22.x );
 
 my %versions = (
-    '5.8.x' => {
-        gbranch => 'maint-5.8',
-        source  => 'perl5.git.perl.org::perl-5.8.x',
+    '5.18.x' => {
+        gbranch => 'maint-5.18',
+        source  => 'perl5.git.perl.org::perl-5.18.x',
         server  => 'http://perl5.git.perl.org',
         sdir    => '/perl.git/snapshot/refs/heads/',
-        sfile   => 'maint-5.8.tar.gz',
-        pdir    => '',
-        ddir    => File::Spec->catdir(
-            cwd(),
-            File::Spec->updir,
-            "perl-$vdirs{'5.8.x'}"
-        ),
-        ftphost => 'public.activestate.com',
-        ftpusr  => 'anonymous',
-        ftppwd  => 'smokers@perl.org',
-        ftpsdir => '/pub/apc/perl-5.8.x',
-        ftpcdir => '/pub/apc/perl-5.8.x-diffs',
-
-        text    => 'Perl 5.8 MAINT',
-        cfg     => (
-            is_win32
-                ? 'w32current.cfg'
-                : is_vms ? 'vmsperl.cfg' : 'perlmaint.cfg'
-        ),
-        is56x   => 0,
-    },
-
-    '5.10.x' => {
-        gbranch => 'maint-5.10',
-        source  => 'perl5.git.perl.org::perl-5.10.x',
-        server  => 'http://perl5.git.perl.org',
-        sdir    => '/perl.git/snapshot/refs/heads/',
-        sfile   => 'maint-5.10.tar.gz',
-        pdir    => '',
-        ddir    => File::Spec->catdir(
-            cwd(),
-            File::Spec->updir,
-            "perl-$vdirs{'5.10.x'}"
-        ),
-        ftphost => 'public.activestate.com',
-        ftpusr  => 'anonymous',
-        ftppwd  => 'smokers@perl.org',
-        ftpsdir => '/pub/apc/perl-5.10.x',
-        ftpcdir => '/pub/apc/perl-5.10.x-diffs',
-
-        text    => 'Perl 5.10 MAINT',
-        cfg     => (
-            is_win32
-                ? 'w32current.cfg'
-                : is_vms ? 'vmsperl.cfg' : 'perlmaint.cfg'
-        ),
-        is56x   => 0,
-    },
-
-    '5.12.x' => {
-        gbranch => 'maint-5.12',
-        source  => 'perl5.git.perl.org::perl-5.12.x',
-        server  => 'http://perl5.git.perl.org',
-        sdir    => '/perl.git/snapshot/refs/heads/',
-        sfile   => 'maint-5.12.tar.gz',
+        sfile   => 'maint-5.18.tar.gz',
         pdir    => '/pub/apc/perl-current-diffs',
         ddir    => File::Spec->catdir(
             cwd(),
             File::Spec->updir,
             'perl-current'
         ),
-        ftphost => 'public.activestate.com',
-        ftpusr  => 'anonymous',
-        ftppwd  => 'smokers@perl.org',
-        ftpsdir => '/pub/apc/perl-current',
-        ftpcdir => '/pub/apc/perl-current-diffs',
 
-        text    => 'Perl 5.12 maint',
+        text    => 'Perl 5.18 maint',
         cfg     => (
             is_win32
                 ? 'w32current.cfg'
@@ -228,25 +169,20 @@ my %versions = (
         ),
         is56x   => 0,
     },
-    '5.14.x' => {
-        gbranch => 'maint-5.14',
-        source  => 'perl5.git.perl.org::perl-5.14.x',
+    '5.20.x' => {
+        gbranch => 'maint-5.20',
+        source  => 'perl5.git.perl.org::perl-5.20.x',
         server  => 'http://perl5.git.perl.org',
         sdir    => '/perl.git/snapshot/refs/heads/',
-        sfile   => 'maint-5.14.tar.gz',
+        sfile   => 'maint-5.20.tar.gz',
         pdir    => '/pub/apc/perl-current-diffs',
         ddir    => File::Spec->catdir(
             cwd(),
             File::Spec->updir,
             'perl-current'
         ),
-        ftphost => 'public.activestate.com',
-        ftpusr  => 'anonymous',
-        ftppwd  => 'smokers@perl.org',
-        ftpsdir => '/pub/apc/perl-current',
-        ftpcdir => '/pub/apc/perl-current-diffs',
 
-        text    => 'Perl 5.14 maint',
+        text    => 'Perl 5.20 maint',
         cfg     => (
             is_win32
                 ? 'w32current.cfg'
@@ -254,25 +190,20 @@ my %versions = (
         ),
         is56x   => 0,
     },
-    '5.16.x' => {
-        gbranch => 'maint-5.16',
-        source  => 'perl5.git.perl.org::perl-5.16.x',
+    '5.22.x' => {
+        gbranch => 'maint-5.22',
+        source  => 'perl5.git.perl.org::perl-5.22.x',
         server  => 'http://perl5.git.perl.org',
         sdir    => '/perl.git/snapshot/refs/heads/',
-        sfile   => 'maint-5.16.tar.gz',
+        sfile   => 'maint-5.22.tar.gz',
         pdir    => '/pub/apc/perl-current-diffs',
         ddir    => File::Spec->catdir(
             cwd(),
             File::Spec->updir,
             'perl-current'
         ),
-        ftphost => 'public.activestate.com',
-        ftpusr  => 'anonymous',
-        ftppwd  => 'smokers@perl.org',
-        ftpsdir => '/pub/apc/perl-current',
-        ftpcdir => '/pub/apc/perl-current-diffs',
 
-        text    => 'Perl 5.16 maint',
+        text    => 'Perl 5.22 maint',
         cfg     => (
             is_win32
                 ? 'w32current.cfg'
@@ -292,13 +223,8 @@ my %versions = (
             File::Spec->updir,
             'perl-current'
         ),
-        ftphost => 'public.activestate.com',
-        ftpusr  => 'anonymous',
-        ftppwd  => 'smokers@perl.org',
-        ftpsdir => '/pub/apc/perl-current',
-        ftpcdir => '/pub/apc/perl-current-diffs',
 
-        text    => 'Perl 5.18 to-be',
+        text    => 'Perl 5.22 to-be',
         cfg     => (
             is_win32
                 ? 'w32current.cfg'
@@ -394,20 +320,20 @@ my %opt = (
                                    'perl-inter' ),
         chk => '.+',
     },
-    fsync => { 
+    fsync => {
         msg => "How would you like to sync your master source-tree?\n$syncmsg",
-        alt => [ @syncers ], 
+        alt => [ @syncers ],
         dft => $syncers[0],
     },
-    sync_type => { 
+    sync_type => {
         msg => "How would you like to sync your source-tree?\n$syncmsg",
-        alt => [ @syncers ], 
+        alt => [ @syncers ],
         dft => $syncers[0],
     },
     source => {
         msg => 'Where would you like to rsync from?',
         alt => [ ],
-        dft => 'ftp.linux.activestate.com::perl-current',
+        dft => 'perl5.git.perl.org::perl-current',
     },
     rsync => {
         msg => 'Which rsync program should be used?',
@@ -481,24 +407,6 @@ Examples:$untarmsg",
         dft => 'tgz',
     },
 
-    patchup => {
-        msg => 'Would you like to try to patchup your snapshot?',
-        alt => [qw( N y ) ],
-        dft => 'n',
-    },
-
-    pserver => {
-        msg => 'Which server would you like the patches FTPed from?',
-        alt => [ ],
-        dft => 'ftp.linux.activestate.com',
-    },
-
-    pdir => {
-        msg => 'Which directory should the patches FTPed from?',
-        alt => [ ],
-        dft => '/pub/staff/gsar/APC/perl-current-diffs',
-    },
-
     unzip => {
         msg => 'How should the patches be unzipped?',
         alt => [ ],
@@ -526,36 +434,6 @@ Examples:$untarmsg",
         chk => '.+',
     },
 
-    ftphost => {
-        msg => 'From which server should the source-tree be FTPed',
-        alt => [ ],
-        dft => 'ftp.linux.activestate.com',
-        chk => '.+',
-    },
-
-    ftpusr  => {
-       msg => undef, #no choise
-       alt => [ ],
-       dft => 'anonymous',
-    },
-    ftppwd  => {
-       msg => '',
-       alt => [ ],
-       dft => 'smokers@perl.org',
-    },
-    ftpsdir => {
-       msg => 'Base directory for mirror on FTP server',
-       alt => [ ],
-       dft => '/pub/staff/gsar/APC/perl-current',
-       chk => '.+',
-    },
-    ftpcdir => {
-        msg => 'Base directory for patches on FTP server',
-        alt => [ ],
-        dft => '/pub/staff/gsar/APC/perl-current-diffs',
-        chk => '.+',
-    },
-
     patchbin => {
         msg => undef,
         alt => [ ],
@@ -621,6 +499,11 @@ EOT
     },
 
     # Test::Smoke::Gateway database
+    poster => {
+        msg => "The type of HTTP POST system to use.",
+        alt => [get_avail_posters()],
+        dft => '',
+    },
     smokedb_url => {
         msg => <<EOT,
 Send smoke results to the SmokeDB? (url)
@@ -639,6 +522,11 @@ EOT
         alt => [qw( always on_fail never )],
         dft => 'never',
     },
+    ua_timeout => {
+        msg => '',
+        alt => [ ],
+        dft => undef,
+    },
 
     # user_note
     user_note => {
@@ -843,7 +731,7 @@ B<Test::Smoke> is the symbolic name for a set of scripts and modules
 that try to run the perl core tests on as many configurations as possible
 and combine the results into an easy to read report.
 
-The main script is F<smokeperl.pl>, and this uses a configuration file
+The main script is F<tssmokeperl.pl>, and this uses a configuration file
 that is created by this program (F<configsmoke.pl>).  There is no default
 configuration as some actions can be rather destructive, so you will need
 to create your own configuration by running this program!
@@ -861,7 +749,7 @@ For MSWin32 this is called F<smokecurrent.cmd> otherwise this is called
 F<smokecurrent.sh>. Again the default prefix can be overridden by specifying
 the C<< -j <prefix> >> or C<< -p <prefix> >> switch.
 
-All output (stdout, stderr) from F<smokeperl.pl> and its sub-processes
+All output (stdout, stderr) from F<tssmokeperl.pl> and its sub-processes
 is redirected to a logfile called F<smokecurrent.log> by the small jcl.
 (Use C<< -l <prefix> >> or C<< -p <prefix> >> to override).
 
@@ -921,7 +809,7 @@ provide a nice way to set the prefix and set the perl_version.
 
 $arg = 'perl_version';
 my $pversion = prompt( $arg );
-$config{ $arg } = $pversion; 
+$config{ $arg } = $pversion;
 
 foreach my $var ( keys %{ $versions{ $pversion } } ) {
     $var eq 'text' and next;
@@ -974,7 +862,7 @@ you will need to confirm your choice.
         my $manifest  = File::Spec->catfile( $config{ $arg }, 'MANIFEST' );
         my $dot_patch = File::Spec->catfile( $config{ $arg }, '.patch' );
         if ( -e $manifest && -e $dot_patch ) {
-            $opt{use_old}->{dft} = $options{oldcfg} && 
+            $opt{use_old}->{dft} = $options{oldcfg} &&
                                    ($conf->{ddir}||"") eq $config{ddir}
                 ? 'y' : $opt{use_old}->{dft};
             my $use_old = prompt_yn( 'use_old' );
@@ -1034,7 +922,7 @@ My plan is to use a few more directories, and avoid make distclean:
 
 =item 1
 
-rsync as before, but to a master directory. this directory is only used 
+rsync as before, but to a master directory. this directory is only used
 for rsyncing from the server
 
 =item 2
@@ -1101,21 +989,21 @@ The default switches passed to B<rsync> are: S<< B<-az --delete> >>
 =item snapshot
 
 This will use B<Net::FTP> to try to find the latest snapshot on
-<ftp://ftp.funet.fi/languages/perl/snap/>. 
+<ftp://ftp.funet.fi/languages/perl/snap/>.
 
 You can also get the perl-5.8.x snapshots (and others) via HTTP
 if you have B<LWP> installed. There are two things you should remember:
 
 =over 8
 
-=item 1. start the server-name B<http://> 
+=item 1. start the server-name B<http://>
 
 =item 2. the snapshot-file must be specified.
 
 =back
 
 Snapshots are not in sync with the repository, so if you have a working
-B<patch> program, you can choose to "upgrade" your snapshot by fetching 
+B<patch> program, you can choose to "upgrade" your snapshot by fetching
 all the seperate patches from the repository and applying them.
 
 =item copy
@@ -1125,7 +1013,7 @@ local source directory.
 
 =item hardlink
 
-This will use B<File::Find> and the B<link> function to copy from a 
+This will use B<File::Find> and the B<link> function to copy from a
 local source directory. (This is also used if you choose "forest".)
 
 =back
@@ -1180,14 +1068,6 @@ SYNCER: {
         last SYNCER;
     };
 
-    /^ftp$/  && do {
-        for $arg (qw( ftphost ftpusr ftpsdir ftpcdir )) {
-            $config{ $arg } = prompt( $arg );
-        }
-        $config{ftppwd} = $conf->{ftppwd} || $opt{ftppwd}{dft};
-
-        last SYNCER;
-    };
 
     /^snapshot$/ && do {
         for $arg ( qw( server sdir sfile ) ) {
@@ -1204,21 +1084,6 @@ SYNCER: {
         $arg = 'tar';
         $config{ $arg } = prompt( $arg );
 
-        $arg = 'patchup';
-        $config{patchbin} ||= find_a_patch();
-        if ( $config{patchbin} ) {
-            $config{ $arg } = prompt_yn( $arg );
-
-            if ( $config{ $arg } ) {
-                for $arg (qw( pserver pdir unzip patchbin )) {
-                    $config{ $arg } = prompt( $arg );
-                }
-                $opt{cleanup}->{msg} .= " 2(patches) 3(both)";
-                $opt{cleanup}->{alt}  = [0, 1, 2, 3];
-            }
-        } else {
-            $config{ $arg } = 0;
-        }
         $arg = 'cleanup';
         $config{ $arg } = prompt( $arg );
 
@@ -1389,13 +1254,13 @@ if ( $config{is56x} ) {
     $config{ $arg } = prompt_yn( $arg );
     if ( is_win32 && ! $config{ $arg } ) {
         print "*** WHOA THERE!!! ***\n";
-        print "\tYou should not try to use PERLIIO=stdio on MSWin332!\n";
+        print "\tYou should not try to use PERLIO=stdio on MSWin332!\n";
     }
 }
 =item locale
 
 C<locale> and its value are passed to F<mktest.pl> and its value is passed
-to F<mkovz.pl>. F<mktest.pl> will do an extra pass of B<make test> with 
+to F<mkovz.pl>. F<mktest.pl> will do an extra pass of B<make test> with
 C<< $ENV{LC_ALL} >> set to that locale (and C<< $ENV{PERL_UNICODE} = ""; >>,
 C<< $ENV{PERLIO} = "perlio"; >>). This feature should only be used with
 UTF8 locales, that is why this is checked (by regex only).
@@ -1436,37 +1301,49 @@ Please send in the smoke-logfile for failures.
 
 =cut
 
-$arg = 'smokedb_url';
 SMOKEDB: {
     eval q{require JSON;};
     my $has_json = !$@;
     if ( !$has_json ) {
-        $config{ $arg } = "";
+        $config{smokedb_url} = $config{poster} = "";
         print "Could not find 'JSON', please install.\n";
         last SMOKEDB;
     }
 
-    eval q{require LWP::UserAgent;};
-    my $has_lwp_useragent = !$@;
-    if ( !$has_lwp_useragent ) {
-        $config{ $arg } = "";
-        print "Could not find 'LWP::UserAgent', please install.\n";
+    if (!@{ $opt{poster}{alt} }) {
+        $config{smokedb_url} = $config{poster} = "";
+        print "Could not find a HTTP poster, no CoreSmokeDB.\n";
         last SMOKEDB;
     }
 
+    $arg = 'smokedb_url';
     $config{ $arg } = prompt( $arg );
-    last SMOKEDB if !$config{ $arg };
+    if (! $config{$arg}) {
+        $config{smokedb_url} = $config{poster} = "";
+        last SMOKEDB;
+    }
+
+    $arg = 'poster';
+    $config{$arg} = prompt($arg);
+    if (! $config{$arg}) {
+        $config{smokedb_url} = $config{poster} = "";
+        last SMOKEDB;
+    }
+    $config{curlbin} = whereis('curl') if $config{poster} eq 'curl';
 
     $arg = 'send_log';
     $config{ $arg } = prompt( $arg );
 
     $arg = 'send_out';
     $config{ $arg } = prompt( $arg );
+
+    $arg = 'ua_timeout';
+    $config{$arg} = $opt{$arg}{dft};
 }
 
 =item mail
 
-C<{mail}> will set the new default for L<smokeperl.pl>
+C<{mail}> will set the new default for L<tssmokeperl.pl>
 
 =item mail_type
 
@@ -1535,7 +1412,7 @@ MAIL: {
     $arg = 'bcc';
     $config{ $arg } = prompt( $arg );
 
-    if ( $config{mail_type} eq 'mailx' && 
+    if ( $config{mail_type} eq 'mailx' &&
          ( $config{cc} || $config{ccp5p_onfail} ) ) {
         $arg = 'swcc';
         $config{ $arg } = prompt( $arg );
@@ -1578,16 +1455,16 @@ EO_MSG
         alt => $compilers{ $config{w32cc} }->{maker},
         dft => ( sort @{ $compilers{ $config{w32cc} }->{maker} } )[-1],
     };
-    $opt{w32make}->{msg} = @{ $compilers{ $config{w32cc} }->{maker} } > 1 
+    $opt{w32make}->{msg} = @{ $compilers{ $config{w32cc} }->{maker} } > 1
         ? "Which make should be used" : undef;
 
     $config{w32make} = prompt( 'w32make' );
     $config{testmake} = $config{testmake};
 
-    $config{w32args} = [ 
+    $config{w32args} = [
         "--win32-cctype" => $config{w32cc},
         "--win32-maker"  => $config{w32make},
-        "osvers=$osvers", 
+        "osvers=$osvers",
         $compilers{ $config{w32cc} }->{ccversarg},
     ];
 }
@@ -1616,7 +1493,7 @@ VMSMAKE: {
 
 =item make finetuning
 
-Two different config options to accomodate the same thing: 
+Two different config options to accomodate the same thing:
 I<parallel build> and I<serial testing>
 
   * makeopt  => used by Test::Smoke::Smoker::_make()
@@ -1684,7 +1561,7 @@ unless ( is_win32 || is_vms ) {
 
 =item v
 
-The verbosity level: 
+The verbosity level:
 
 =over 8
 
@@ -1716,11 +1593,11 @@ $config{ $arg } = prompt_yn( $arg );
 
 =item killtime
 
-When C<< $Config{d_alarm} >> is found we can use C<alarm()> to abort 
+When C<< $Config{d_alarm} >> is found we can use C<alarm()> to abort
 long running smokes. Leave this value empty to keep the old behaviour.
 
-    07:30 => F<smokeperl.pl> is aborted on 7:30 localtime
-   +23:45 => F<smokeperl.pl> is aborted after 23 hours and 45 minutes
+    07:30 => F<tssmokeperl.pl> is aborted on 7:30 localtime
+   +23:45 => F<tssmokeperl.pl> is aborted after 23 hours and 45 minutes
 
 Thank you Jarkko for donating this suggestion.
 
@@ -1753,7 +1630,7 @@ $config{lfile} = File::Spec->rel2abs( $options{log}, cwd );
 Some filesystems do not support opening an already opened file. This
 makes it hard to scan the logfile for compiler messages. We can delay
 the creation of the report and call F<mailrpt.pl> after
-F<smokeperl.pl>. VMS might benefit.
+F<tssmokeperl.pl>. VMS might benefit.
 
 =cut
 
@@ -1802,7 +1679,7 @@ P5OPT: {
 
 =item cron/crontab
 
-We try to detect 'crontab' or 'cron', read the contents of 
+We try to detect 'crontab' or 'cron', read the contents of
 B<crontab -l>, detect ourself and comment us out.
 Then we add an new entry.
 
@@ -1933,7 +1810,7 @@ If C<< Data::Dumper->can('Sortkeys') >> it will order the keys.
 
 sub save_config {
     my $dumper = Data::Dumper->new([ \%config ], [ 'conf' ]);
-    Data::Dumper->can( 'Sortkeys' ) and 
+    Data::Dumper->can( 'Sortkeys' ) and
         $dumper->Sortkeys( \&sort_configkeys );
     local *CONFIG;
     open CONFIG, "> $options{config}" or
@@ -1953,7 +1830,7 @@ Order and grouping by Merijn, thanks!
 =cut
 
 sub sort_configkeys {
-    my @order = ( 
+    my @order = (
         # Test::Smoke (startup) related
         qw( cfg v smartsmoke renice killtime umask ),
 
@@ -1962,8 +1839,7 @@ sub sort_configkeys {
 
         # Sync related
         qw( sync_type fsync rsync opts source tar server sdir sfile
-            patchup pserver pdir unzip patchbin cleanup cdir hdir pfile
-            ftphost ftpusr ftppwd ftpsdir ftpcdir
+            unzip patchbin cleanup cdir hdir pfile
             gitbin gitdir gitorigin gitdfbranch gitbranchfile ),
 
         # OS specific make related
@@ -1977,7 +1853,7 @@ sub sort_configkeys {
             swcc cc swbcc bcc ),
 
         #SmokeDB
-        qw( smokedb_url send_log send_out ),
+        qw( smokedb_url send_log send_out ua_timeout ),
 
         # Archive reports and logfile
         qw( adir lfile ),
@@ -1995,11 +1871,11 @@ sub sort_configkeys {
     my $i = 0;
     my %keyorder = map { $_ => $i++ } @order;
 
-    my @keyord = sort { 
-        $a <=> $b 
+    my @keyord = sort {
+        $a <=> $b
     } @keyorder{ grep exists $keyorder{ $_}, keys %{ $_[0] } };
 
-    return [ @order[ @keyord ], 
+    return [ @order[ @keyord ],
              sort grep !exists $keyorder{ $_ }, keys %{ $_[0] } ];
 }
 
@@ -2012,8 +1888,8 @@ C<write_sh()> creates the shell-script.
 sub write_sh {
     my $cwd = cwd();
     my $jcl = "$options{jcl}.sh";
-    my $smokeperl = File::Spec->catfile( $findbin, 'smokeperl.pl' );
-    my $cronline = schedule_entry( File::Spec->catfile( $cwd, $jcl ), 
+    my $smokeperl = File::Spec->catfile( $findbin, 'tssmokeperl.pl' );
+    my $cronline = schedule_entry( File::Spec->catfile( $cwd, $jcl ),
                                    $cron, $crontime );
 
     my $p5lib = $config{perl5lib} ? <<EO_P5LIB : '';
@@ -2026,8 +1902,8 @@ export PERL5OPT
 EO_P5OPT
 
     my $handle_lock = $config{killtime} ? <<EO_CONT : <<EO_DIE;
-    # Not sure about this, so I will keep the old behaviour 
-    # smokeperl.pl will exit(42) on timeout
+    # Not sure about this, so I will keep the old behaviour
+    # tssmokeperl.pl will exit(42) on timeout
     # continue='--continue'
     echo "We seem to be running (or remove \$LOCKFILE)" >& 2
     exit 200
@@ -2085,9 +1961,9 @@ sub write_bat {
     my $cwd = File::Spec->canonpath( cwd() );
     my $findbin_bin = File::Spec->canonpath( $findbin );
 
-    my $smokeperl  = File::Spec->catfile( $findbin_bin, 'smokeperl.pl' );
-    my $archiverpt = File::Spec->catfile( $findbin_bin, 'archiverpt.pl' );
-    my $mailrpt    = File::Spec->catfile( $findbin_bin, 'mailrpt.pl' );
+    my $smokeperl  = File::Spec->catfile( $findbin_bin, 'tssmokeperl.pl' );
+    my $archiverpt = File::Spec->catfile( $findbin_bin, 'tsarchive.pl' );
+    my $mailrpt    = File::Spec->catfile( $findbin_bin, 'tssendrpt.pl' );
     my $copycmd = <<'EOCOPYCMD';
 
 REM I found hanging XCOPY while smoking; uncommenting the next line might help
@@ -2105,7 +1981,7 @@ EO_P5OPT
 
 
     my $jcl = "$options{jcl}.cmd";
-    my $atline = schedule_entry( File::Spec->catfile( $cwd, $jcl ), 
+    my $atline = schedule_entry( File::Spec->catfile( $cwd, $jcl ),
                                  $cron, $crontime );
 
     my $archive = qq/$^X $archiverpt -c "\%CFGNAME\%"/;
@@ -2146,8 +2022,8 @@ if NOT EXIST \%LOCKFILE\% goto START_SMOKE
     set OLD_PATH=\%PATH\%
     set PATH=$findbin_bin;\%PATH\%
     $^X $smokeperl -c "\%CFGNAME\%" \%* > "\%WD\%\\$options{log}" 2>&1
-    $archive
-    $report
+    REM $report
+    REM $archive
     set PATH=\%OLD_PATH\%
 
 del \%LOCKFILE\%
@@ -2190,7 +2066,7 @@ sub write_com {
 \$$p5opt
 \$! DEFINE/USER sys\$output $options{log}
 \$! DEFINE/USER sys\$error $options{log}
-\$  MCR $^X ${findbin}smokeperl.pl "-c=$options{config}"
+\$  MCR $^X ${findbin}tssmokeperl.pl "-c=$options{config}"
 EO_COM
     close MYSMOKECOM or warn "Error writing '$jcl': $!";
 
@@ -2200,7 +2076,7 @@ EO_COM
 }
 
 sub prompt {
-    my( $message, $alt, $df_val, $chk, $nck ) = 
+    my( $message, $alt, $df_val, $chk, $nck ) =
         @{ $opt{ $_[0] } }{qw( msg alt dft chk nck )};
 
     $df_val = $conf->{ $_[0] } if exists $conf->{ $_[0] };
@@ -2212,7 +2088,7 @@ sub prompt {
     }
 
     $message =~ s/\s+$//;
-        
+
     my %ok_val;
     %ok_val = map { (lc $_ => 1) } @$alt if @$alt;
     $chk ||= '.*';
@@ -2238,7 +2114,7 @@ sub prompt {
         } elsif ( $input eq '&-d' ) {
             $options{usedft} = 1;
             print "(OK, We'll run with --des from now on.)\n";
-            redo INPUT; 
+            redo INPUT;
         } else {
             $input =~ s/^\s+//;
             $input =~ s/\s+$//;
@@ -2247,7 +2123,7 @@ sub prompt {
 
         print "Input should not match: '/$nck/i'\n" and redo INPUT
             if $nck && $input =~ m/$nck/i;
-        
+
         print "Input does not match: 'm/$chk/'\n" and redo INPUT
             unless $input =~ m/$chk/i;
 
@@ -2267,7 +2143,7 @@ sub chk_dir {
     defined $dir or return;
     my $cwd = cwd();
     File::Path::mkpath( $dir, 1, 0755 ) unless -d $dir;
- 
+
     if ( ! chdir $dir  ) {
         warn "Cannot chdir($dir): $!\n";
         $dir = undef;
@@ -2287,10 +2163,10 @@ sub prompt_dir {
     }
 
     GETDIR: {
-    
+
 
         my $dir = prompt( @_ );
-        if ( $dir eq "" && ! @{ $opt{ $_[0] }->{alt} } && 
+        if ( $dir eq "" && ! @{ $opt{ $_[0] }->{alt} } &&
              ! $opt{ $_[0] }->{chk} ) {
             print "Got []\n";
             return "";
@@ -2298,8 +2174,8 @@ sub prompt_dir {
 
         # thanks to perlfaq5
         $dir =~ s{^ ~ ([^/]*)}
-                 {$1 ? ( getpwnam $1 )[7] : 
-                       ( $ENV{HOME} || $ENV{LOGDIR} || 
+                 {$1 ? ( getpwnam $1 )[7] :
+                       ( $ENV{HOME} || $ENV{LOGDIR} ||
                          "$ENV{HOMEDRIVE}$ENV{HOMEPATH}" )}ex;
 
         defined( $dir = chk_dir( $dir ) ) or redo GETDIR;
@@ -2318,7 +2194,7 @@ sub prompt_file {
 
         # thaks to perlfaq5
         $file =~ s{^ ~ ([^/]*)}
-                  {$1 ? ( getpwnam $1 )[7] : 
+                  {$1 ? ( getpwnam $1 )[7] :
                    ( $ENV{HOME} || $ENV{LOGDIR} ||
                    "$ENV{HOMEDRIVE}$ENV{HOMEPATH}" )}ex;
         $file = File::Spec->rel2abs( $file ) unless !$file && $no_valid;
@@ -2348,13 +2224,7 @@ sub prompt_yn {
 }
 
 sub find_a_patch {
-
-    my $patch_bin;
-    foreach my $patch (qw( gpatch npatch patch )) {
-        $patch_bin = whereis( $patch ) or next;
-        my $version = `$patch_bin -version`;
-        $? or return $patch_bin;
-    }
+    return (get_avail_patchers())[0];
 }
 
 sub renice {
@@ -2370,60 +2240,6 @@ EOCOMMENT
 
 }
 
-sub get_avail_sync {
-
-    my @synctype = qw( copy hardlink );
-    eval { local $^W; require Net::FTP };
-    my $has_ftp = !$@;
-
-    eval { local $^W; require LWP::Simple };
-    my $has_lwp = !$@;
-
-    my $pversion = $config{perl_version} || 'blead';
-
-    # (has_ftp && 5.9.x) || has_lwp
-    unshift @synctype, 'snapshot' 
-        if ( $has_ftp && $pversion eq 'blead' ) || $has_lwp;
-
-    unshift @synctype, 'ftp' if $has_ftp;
-
-    unshift @synctype, 'rsync' if whereis( 'rsync' );
-
-    unshift @synctype, 'git' if whereis('git');
-
-    return @synctype;
-}
-
-sub get_avail_tar {
-
-    my $use_modules = 0;
-    eval { require Archive::Tar };
-    unless ( $@ ) {
-        if ( eval "$Archive::Tar::VERSION" >= 0.99 ) {
-            eval { require IO::Zlib };
-        } else {
-            eval { require Compress::Zlib };
-        }
-        $use_modules = !$@;
-    }
-
-    my $fmt = tar_fmt();
-
-    return $fmt && $use_modules 
-        ? ( $fmt, 'Archive::Tar' )
-        : $fmt ? ( $fmt ) : $use_modules ? ( 'Archive::Tar' ) : ();
-    
-}
-
-sub tar_fmt {
-    my $tar  = whereis( 'tar' );
-    my $gzip = whereis( 'gzip' );
-
-    return $tar && $gzip 
-        ? "$gzip -cd %s | $tar -xf -"
-        : $tar ? "tar -xzf %s" : "";
-}
-
 sub check_locale {
     # I only know one way... and one for Darwin (perhaps FreeBSD)
     if ( $^O =~ /darwin|bsd/i ) {
@@ -2432,7 +2248,7 @@ sub check_locale {
         my @list = grep /utf-?8$/i => readdir USL;
         closedir USL;
         return @list;
-    } 
+    }
     my $locale = whereis( 'locale' );
     return unless $locale;
     return grep /utf-?8$/i => split /\n/, `$locale -a`;
@@ -2465,94 +2281,10 @@ sub schedule_entry {
     return $entry;
 }
 
-sub get_avail_mailers {
-    my %map;
-    my $mailer = 'mail';
-    $map{ $mailer } = whereis( $mailer );
-    $mailer = 'mailx';
-    $map{ $mailer } = whereis( $mailer );
-    {
-        $mailer = 'sendmail';
-        local $ENV{PATH} = "$ENV{PATH}$Config{path_sep}/usr/sbin";
-        $map{ $mailer } = whereis( $mailer );
-    }
-    $mailer = 'sendemail';
-    $map{ $mailer } = whereis( $mailer );
-
-    eval { require Mail::Sendmail };
-    $map{ 'Mail::Sendmail' } = $@ ? '' : 'Mail::Sendmail';
-
-    eval { require MIME::Lite };
-    $map{ 'MIME::Lite' } = $@ ? '' : 'MIME::Lite';
-
-    return map { ( $_ => $map{ $_ }) } grep length $map{ $_ } => keys %map;
-}
-        
-sub get_avail_w32compilers {
-
-    my %map = (
-        MSVC => { ccname => 'cl',    maker => [ 'nmake' ] },
-        BCC  => { ccname => 'bcc32', maker => [ 'dmake' ] },
-        GCC  => { ccname => 'gcc',   maker => [ 'dmake' ] },
-    );
-
-    my $CC = 'MSVC';
-    if ( $map{ $CC }->{ccbin} = whereis( $map{ $CC }->{ccname} ) ) {
-        # No, cl doesn't support --version (One can but try)
-        my $output =`"$map{ $CC }->{ccbin}" --version 2>&1`;
-        my $ccvers = $output =~ /^.*Version\s+([\d.]+)/ ? $1 : '?';
-        $map{ $CC }->{ccversarg} = "ccversion=$ccvers";
-        my $mainvers = $ccvers =~ /^(\d+)/ ? $1 : 1;
-        $map{ $CC }->{CCTYPE} = $mainvers < 12 ? 'MSVC' : 'MSVC60';
-    }
-
-    $CC = 'BCC';
-    if ( $map{ $CC }->{ccbin} = whereis( $map{ $CC }->{ccname} ) ) {
-        # No, bcc32 doesn't support --version (One can but try)
-        my $output = `"$map{ $CC }->{ccbin}" --version 2>&1`;
-        my $ccvers = $output =~ /([\d.]+)/ ? $1 : '?';
-        $map{ $CC }->{ccversarg} = "ccversion=$ccvers";
-        $map{ $CC }->{CCTYPE} = 'BORLAND';
-    }
-
-    $CC = 'GCC';
-    if ( $map{ $CC }->{ccbin} = whereis( $map{ $CC }->{ccname} ) ) {
-        local *STDERR;
-        open STDERR, ">&STDOUT"; #do we need an error?
-        select( (select( STDERR ), $|++ )[0] );
-        my $output = `"$map{ $CC }->{ccbin}" --version`;
-        my $ccvers = $output =~ /(\d+.*)/ ? $1 : '?';
-        $ccvers =~ s/\s+copyright.*//i;
-        $map{ $CC }->{ccversarg} = "gccversion=$ccvers";
-        $map{ $CC }->{CCTYPE} = $CC
-    }
-
-    return map {
-       ( $map{ $_ }->{CCTYPE} => $map{ $_ } )
-    } grep length $map{ $_ }->{ccbin} => keys %map;
-}
-
-sub get_avail_vms_make {
-
-    return map +( $_ => undef ) => grep defined $_ && length( $_ ) 
-        => map whereis( $_ ) => qw( MMK MMS );
- 
-    local *QXERR; open *QXERR, ">&STDERR"; close STDERR;
-
-    my %makers = map {
-        my $maker = $_;
-        map +( $maker => /V([\d.-]+)/ ? $1 : '' )
-        => grep /\b$maker\b/ && /V[\d.-]+/ => qx($maker/IDENT)
-    } qw( MMK MMS );
-
-    open STDERR, ">&QXERR"; close QXERR;
-
-    return %makers;
-}
-
 sub get_Win_version {
-    require Test::Smoke::SysInfo;
-    ( my $win_version = Test::Smoke::SysInfo::__get_os() ) =~ s/^[^-]*- //;
+    require Test::Smoke::SysInfo::Windows;
+    my $si = Test::Smoke::SysInfo::Windows->new();
+    (my $win_version = $si->os) =~ s/^[^-]*- //;
     return $win_version;
 }
 
@@ -2581,7 +2313,7 @@ sub default_buildcfg {
         -f $dftbcfg and last;
     }
     -f $dftbcfg
-        or die "You seem to have an incomplete Test::Smoke installation" . 
+        or die "You seem to have an incomplete Test::Smoke installation" .
                "($basename is missing)!\n";
     copy $dftbcfg, $file_name
         and print "\nCreated buildconfig '$file_name'";
@@ -2615,7 +2347,7 @@ sub check_buildcfg {
     my( $os, $osver ) = split /\s+-\s+/, $uname_s;
     # May assume much too much about OS version number formats.
     my( $osvermaj, $osvermin ) = ($osver =~ /^\D*(\d+)\D+(\d+)/);
-    $osver = sprintf "%s", $osvermaj || '?'; 
+    $osver = sprintf "%s", $osvermaj || '?';
     defined $osvermin and $osver .= sprintf ".%03d", $osvermin;
 
 
@@ -2630,7 +2362,7 @@ sub check_buildcfg {
             last OSCHECK;
         };
 
-        $os =~ /darwin|bsd/i && do { 
+        $os =~ /darwin|bsd/i && do {
             push @no_option, qw( -Duselongdouble -Dusemorebits -Duse64bitall );
         };
 
@@ -2658,7 +2390,7 @@ sub check_buildcfg {
         length( $b||"" ) <=> length( $a||"" )
     } @no_option;
 
-    my $display = join "", map "\t$_" 
+    my $display = join "", map "\t$_"
         => grep !/^#/ || ( /^#/ && /$options/ ) => @bcfg;
     $opt{change_cfg}->{msg} = <<EOMSG;
 Some options that do not apply to your platform were found.
@@ -2685,7 +2417,7 @@ sub finish_cfgcheck {
     if ( $overwrite ) {
         my $backup = "$fname.bak";
         -f $backup and chmod( 0775, $backup ) and 1 while unlink $backup;
-        rename $fname, $backup or 
+        rename $fname, $backup or
             warn "Cannot rename '$fname' to '$backup': $!";
     } else {
         $fname = "$options{prefix}.cfg.save";
