@@ -1,9 +1,7 @@
 package Test::Smoke::App::Base;
 use warnings;
 use strict;
-use Carp qw/ confess /;
-
-our $VERSION = '0.002';
+use Carp;
 
 use base 'Test::Smoke::ObjectBase';
 
@@ -12,7 +10,6 @@ use Getopt::Long qw/:config pass_through/;
 use Test::Smoke::App::AppOption;
 use Test::Smoke::App::AppOptionCollection;
 use Test::Smoke::LogMixin;
-use Test::Smoke::Util::Serialise qw/serialise/;
 
 =head1 NAME
 
@@ -201,7 +198,7 @@ sub process_options {
 
 Return the value of an option.
 
-=head3 Arguments
+=head3 Argumens
 
 Positional.
 
@@ -246,9 +243,9 @@ sub option {
             return $opts->{$option} if $is_special;
         }
 
-        confess("Option '$option' is not valid.");
+        croak("Option '$option' is not valid.");
     }
-    confess("Invalid option '$option'");
+    croak("Invalid option '$option'");
 }
 
 sub _find_option {
@@ -352,12 +349,8 @@ sub _get_options {
     my $self = shift;
 
     %{$self->{_cli_options}} = %{$self->opt_collection->options_for_cli};
-
-    @{$self->{_ARGV}} = @{$self->{_ARGV_EXTRA}} = @ARGV;
-
-    my $parser = Getopt::Long::Parser->new(config => [qw/no_ignore_case passthrough/]);
-    $parser->getoptionsfromarray(
-        $self->{_ARGV_EXTRA},
+    @{$self->{_ARGV}} = @ARGV;
+    GetOptions(
         $self->cli_options,
         @{ $self->opt_collection->options_list },
     );
@@ -386,10 +379,7 @@ sub _post_process_options {
         $value = '<undef>' if !defined $value;
         push(
             @errors,
-            sprintf(
-                "Invalid value '%s' for option '%s'",
-                $self->_show_option_value($opt), $opt
-            )
+            sprintf("Invalid value '%s' for option '%s'", $value, $opt)
         ) if !$oo->allowed($self->final_options->{$opt});
     }
     if (@errors) {
@@ -410,23 +400,15 @@ sub _post_process_options {
         for my $opt (sort keys %options) {
             printf "  %-20s| %s\n",
                 $opt,
-                $self->_show_option_value($opt) || '?';
+                $self->option($opt) || '?';
         }
         exit(0);
     }
 }
 
-sub _show_option_value {
-    my $self =  shift;
-    my ($option_name) = @_;
-
-    return serialise( $self->option($option_name) );
-}
-
 sub _obtain_config_file {
     my $self = shift;
     $self->{_from_configfile} = {};
-    $self->{_configfile_error} = undef;
 
     my $cf_name = $self->cli_options->{'configfile'};
     return if !$cf_name;
@@ -438,16 +420,16 @@ sub _obtain_config_file {
     }
 
     if (-f $cf_name) {
-        my $abs_cf = $self->cli_options->{'configfile'} = abs_path($cf_name);
+        $self->cli_options->{'configfile'} = abs_path($cf_name);
 
         # Read the config-file in a localized environment
         our $conf;
         local $conf;
-        delete $INC{$abs_cf};
-        eval { local $^W; require $abs_cf };
+        delete $INC{$cf_name};
+        eval { local $^W; require $cf_name };
         $self->{_configfile_error} = $@;
         %{$self->from_configfile} = %{ $conf || {} };
-        delete $INC{$abs_cf};
+        delete $INC{$cf_name};
         $self->from_configfile->{verbose} = delete($self->from_configfile->{v})
             if exists $self->from_configfile->{v};
     }
