@@ -2,8 +2,6 @@ package Test::Smoke::App::SyncTree;
 use warnings;
 use strict;
 
-our $VERSION = '0.001';
-
 use base 'Test::Smoke::App::Base';
 
 use Test::Smoke::Syncer;
@@ -53,7 +51,7 @@ sub new {
     my $self = $class->SUPER::new(@_);
 
     $self->{_syncer} = Test::Smoke::Syncer->new(
-        $self->option('sync_type'),
+        $self->option('syncer'),
         $self->options,
         v => $self->option('verbose'),
     );
