@@ -3,11 +3,10 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = '0.001';
-
 use Cwd qw/:DEFAULT abs_path/;
 use File::Spec::Functions qw/:DEFAULT rel2abs/;
 use Test::Smoke::Poster::Curl;
+use Test::Smoke::Poster::HTTP_Lite;
 use Test::Smoke::Poster::HTTP_Tiny;
 use Test::Smoke::Poster::LWP_UserAgent;
 
@@ -41,26 +40,30 @@ my %CONFIG = (
 
     df_ua_timeout => undef,
 
-    df_curlargs => [ ],
-
     'LWP::UserAgent' => {
         allowed  => [qw/ua_timeout/],
         required => [],
         class    => 'Test::Smoke::Poster::LWP_UserAgent',
     },
+    'HTTP::Lite' => {
+        allowed => [],
+        required => [],
+        class => 'Test::Smoke::Poster::HTTP_Lite',
+    },
     'HTTP::Tiny' => {
-        allowed => [qw/ua_timeout/],
+        allowed => [],
         required => [],
         class => 'Test::Smoke::Poster::HTTP_Tiny',
     },
     'curl' => {
-        allowed => [qw/curlbin curlargs ua_timeout/],
+        allowed => [qw/curlbin/],
         required => [qw/curlbin/],
         class => 'Test::Smoke::Poster::Curl',
     },
 
     valid_type => {
         'LWP::UserAgent' => 1,
+        'HTTP::Lite'     => 1,
         'HTTP::Tiny'     => 1,
     },
 
