@@ -2,13 +2,9 @@ package Test::Smoke::Poster::Curl;
 use warnings;
 use strict;
 
-our $VERSION = '0.001';
-
 use base 'Test::Smoke::Poster::Base';
 
-use File::Temp qw(tempfile);
-use URI::Escape qw(uri_escape);
-
+use CGI::Util ();                # escape() for HTML
 use Test::Smoke::Util::Execute;
 
 =head1 NAME
@@ -55,30 +51,13 @@ sub _post_data {
     $self->log_info("Posting to %s via %s.", $self->smokedb_url, $self->poster);
     $self->log_debug("Report data: %s", my $json = $self->get_json);
 
-    my $form_data = sprintf("json=%s", uri_escape($json));
-    my ($fh, $filename) = tempfile('curl-tsrepostXXXXXX', TMPDIR => 1);
-    print $fh $form_data;
-    close($fh);
-
+    my $form_data = sprintf("json=%s", CGI::Util::escape($json));
     my $response = $self->curl->run(
+        ($self->v ? () : '--silent'),
         '-A' => $self->agent_string(),
-        '-d' => "\@$filename",
-        ($self->ua_timeout    ? ('--max-time' => $self->ua_timeout) : ()),
-        ($self->curl->verbose ? () : '--silent'),
-        @{ $self->curlargs },
+        '-d' => $form_data,
         $self->smokedb_url,
     );
-    1 while unlink($filename);
-
-    if ($self->curl->exitcode) {
-        $self->log_warn("[POST] curl exitcode: %d %s", $self->curl->exitcode, $response || '');
-        die sprintf(
-            "POST to '%s' curl failed: %d\n",
-            $self->smokedb_url,
-            $self->curl->exitcode
-        );
-    }
-
     $self->log_debug("[CoreSmokeDB] %s", $response);
 
     return $response;
