@@ -2,8 +2,6 @@ package Test::Smoke::Syncer::Git;
 use warnings;
 use strict;
 
-our $VERSION = '0.029';
-
 use base 'Test::Smoke::Syncer::Base';
 
 =head1 Test::Smoke::Syncer::Git
@@ -34,22 +32,17 @@ Keys for C<%args>:
 
 Do the actual syncing.
 
-There are 2 repositories, they both need to be updated:
+=over
 
-The first (proxy) repository has the github.com/Perl repository as its
-(origin) remote. The second repository is used to run the smoker from.
+=item New clone
+  git clone <gitorigin> <gitdir>
+  git clone <gitdir> --reference <gitdir> <ddir>
 
-For the proxy-repository we do:
+=item Existing clone
+  cd <ddir>
+  git pull
 
-    git fetch --all
-    git remote prune origin
-    git reset --hard origin/$gitbranch
-
-For the working-repository we do:
-
-    git clean -dfx
-    git fetch --all
-    git reset --hard origin/$gitbranch
+=back
 
 =cut
 
@@ -62,7 +55,6 @@ sub sync {
     );
     use Carp;
     my $cwd = cwd();
-    # Handle the proxy-clone
     if ( ! -d $self->{gitdir} || ! -d catdir($self->{gitdir}, '.git') ) {
         my $cloneout = $gitbin->run(
             clone => $self->{gitorigin},
@@ -70,65 +62,61 @@ sub sync {
             '2>&1'
         );
         if ( my $gitexit = $gitbin->exitcode ) {
-            croak("Cannot make initial clone: $self->{gitbin} exit $gitexit");
+            croak("Cannot make inital clone: $self->{gitbin} exit $gitexit");
         }
-        $self->log_debug("[git clone from $self->{gitorigin}]: $cloneout");
+        $self->log_debug($cloneout);
     }
 
     my $gitbranch = $self->get_git_branch;
     chdir $self->{gitdir} or croak("Cannot chdir($self->{gitdir}): $!");
-    $self->log_debug("chdir($self->{gitdir})");
 
-    my $gitout = $gitbin->run(remote => 'update', '--prune', '2>&1');
-    $self->log_debug("gitorigin(update --prune): $gitout");
+    # SMOKE_ME
+    my $gitout = $gitbin->run(pull => '--all');
+    $self->log_debug($gitout);
+
+    $gitout = $gitbin->run(remote => prune => 'origin');
+    $self->log_debug($gitout);
 
     $gitout = $gitbin->run(checkout => $gitbranch, '2>&1');
-    $self->log_debug("gitorigin(checkout): $gitout");
+    $self->log_debug($gitout);
 
-    $gitout = $gitbin->run(reset => '--hard', "origin/$gitbranch", '2>&1');
-    $self->log_debug("gitorigin(reset --hard): $gitout");
-
-    # Now handle the working-clone
     chdir $cwd or croak("Cannot chdir($cwd): $!");
-    $self->log_debug("chdir($cwd)");
-    # make the working-clone if it doesn't exist yet
+    # make the smoke clone
     if ( ! -d $self->{ddir} || ! -d catdir($self->{ddir}, '.git') ) {
         # It needs to be empty ...
         my $cloneout = $gitbin->run(
             clone         => $self->{gitdir},
+            '--reference' => $self->{gitdir},
             $self->{ddir},
             '2>&1'
         );
         if ( my $gitexit = $gitbin->exitcode ) {
             croak("Cannot make smoke clone: $self->{gitbin} exit $gitexit");
         }
-        $self->log_debug("[git clone $self->{gitdir}]: $cloneout");
+        $self->log_debug($cloneout);
     }
 
     chdir $self->{ddir} or croak("Cannot chdir($self->{ddir}): $!");
-    $self->log_debug("chdir($self->{ddir})");
 
-    # reset the working-dir to HEAD of the last branch smoked
-    $gitout = $gitbin->run(reset => '--hard', 'HEAD', '2>&1');
-    $self->log_debug("working-dir(reset --hard): $gitout");
+    $gitout = $gitbin->run(reset => '--hard');
+    $self->log_debug($gitout);
 
-    # remove all untracked files and dirs
-    $gitout = $gitbin->run(clean => '-dfx', '2>&1');
-    $self->log_debug("working-dir(clean -dfx): $gitout");
+    $gitout = $gitbin->run(clean => '-dfx');
+    $self->log_debug($gitout);
 
-    # update from origin
-    $gitout = $gitbin->run(fetch => 'origin', '2>&1');
-    $self->log_debug("working-dir(fetch origin): $gitout");
+    $gitout = $gitbin->run(pull => '--all');
+    $self->log_debug($gitout);
 
-    # now checkout the branch we want smoked
+    # SMOKE_ME
     $gitout = $gitbin->run(checkout => $gitbranch, '2>&1');
-    $self->log_debug("working-dir(checkout $gitbranch): $gitout");
+    $self->log_debug($gitout);
 
-    # Make sure HEAD is exactly what the branch is
-    $gitout = $gitbin->run(reset => '--hard', "origin/$gitbranch", '2>&1');
-    $self->log_debug("working-dir(reset --hard): $gitout");
-
-    $self->make_dot_patch();
+    my $mk_dot_patch = Test::Smoke::Util::Execute->new(
+        command => "$^X Porting/make_dot_patch.pl > .patch",
+        verbose => $self->verbose,
+    );
+    my $perlout = $mk_dot_patch->run();
+    $self->log_debug($perlout);
 
     chdir $cwd;
 
@@ -151,7 +139,7 @@ sub get_git_branch {
     if (open my $fh, '<', $self->{gitbranchfile}) {
         $self->log_debug("Reading branch to smoke from: '$self->{gitbranchfile}'");
 
-        chomp( my $branch = <$fh> );
+        my $branch = <$fh>;
         close $fh;
         return $branch;
     }
