@@ -2,8 +2,6 @@ package Test::Smoke::Syncer::Rsync;
 use warnings;
 use strict;
 
-our $VERSION = '0.029';
-
 use base 'Test::Smoke::Syncer::Base';
 
 =head1 Test::Smoke::Syncer::Rsync
@@ -17,7 +15,6 @@ user-calls on this.
 use Cwd;
 use Test::Smoke::LogMixin;
 use Test::Smoke::Util::Execute;
-use Text::ParseWords;
 
 =head2 Test::Smoke::Syncer::Rsync->new( %args )
 
@@ -73,7 +70,7 @@ sub sync {
         Carp::croak( "[rsync] Cannot chdir($self->{ddir}): $!" );
     };
     my $rsyncout = $rsync->run(
-        shellwords($self->{opts}),
+        $self->{opts},
         ($self->verbose ? "-v" : ""),
         $self->{source},
         File::Spec->curdir,
