@@ -2,8 +2,6 @@ package Test::Smoke::SysInfo::Linux;
 use warnings;
 use strict;
 
-our $VERSION = '0.001';
-
 use base 'Test::Smoke::SysInfo::Base';
 
 =head1 NAME
@@ -90,14 +88,8 @@ sub prepare_os {
 
     if ( $os{DISTRIB_DESCRIPTION} ) {
         $distro = $os{DISTRIB_DESCRIPTION};
-        $os{DISTRIB_CODENAME} && $distro !~ m{\b$os{DISTRIB_CODENAME}\b}i and
+        $os{DISTRIB_CODENAME} && $distro !~ m{\b$os{DISTRIB_CODENAME}\b} and
             $distro .= " ($os{DISTRIB_CODENAME})";
-        if ( $os{VERSION_ID} && $distro !~ m{\b$os{VERSION_ID}\b}i ) {
-            $distro .= " $os{VERSION_ID}";
-        }
-        elsif ( $os{DISTRIB_RELEASE} && $distro !~ m{\b$os{DISTRIB_RELEASE}\b}i ) {
-            $distro .= " $os{DISTRIB_RELEASE}";
-        }
     }
     elsif ( $os{PRETTY_NAME} ) {
         $distro = $os{PRETTY_NAME};          # "openSUSE 12.1 (Asparagus) (x86_64)"
