@@ -33,6 +33,7 @@ my %opt = (
     v            => undef,
 
     smokedb_url => undef,
+    ua_timeout  => undef,
 
     rptfile    => 'mktest.rpt',
     jsnfile    => 'mktest.jsn',
@@ -160,9 +161,15 @@ if ($json && $opt{smokedb_url}) {
     require LWP::UserAgent;
     my $ua = LWP::UserAgent->new(
         agent => "Test::Smoke/$Test::Smoke::VERSION",
+        (
+            defined $opt{ua_timeout}
+                ? (timeout => $opt{ua_timeout})
+                : ()
+        ),
     );
     $opt{v} and print "Posting to SmokeDB ($opt{smokedb_url})\n";
-    my $response = $ua->post($opt{smokedb_url}, {json => $json});
+    my $response = eval {$ua->post($opt{smokedb_url}, {json => $json})};
+    print $@ if $@
     $opt{v} and print $response->content;
 }
 
@@ -181,7 +188,7 @@ sub check_for_report {
     my $reporter = Test::Smoke::Reporter->new( $conf );
     if ( defined $reporter->{_outfile} ) {
         $reporter->write_to_file;
-    
+
         if (!-f $report) {
             die "Hmmm... cannot find [$report]";
         }
@@ -204,11 +211,11 @@ sub check_for_json {
             return $json;
         }
         else {
-            $opt{v} and print "Not reuising existing JSON, regenerate\n";
+            $opt{v} and print "Not reusing existing JSON, regenerate\n";
         }
     }
     else {
-        $opt{v} and print "No json found in [$opt{ddir}]\n";
+        $opt{v} and print "No JSON found in [$opt{ddir}]\n";
     }
 
     my $reporter = Test::Smoke::Reporter->new($conf);
